@@ -75,7 +75,7 @@ def write_posts():
 
 def generate(config='settings.py'):
     load_settings(config)
-    load_posts(g.source_directory)
+    load_posts(settings.source)
     write_posts()
 
 
@@ -147,17 +147,22 @@ def launch_help():
 
 
 def __load_themes():
+    import time
     import tempfile
     f = os.path.join(tempfile.gettempdir(), 'liquidluck.json')
-    if os.path.exists(f):
-        content = open(f).read()
-    else:
+
+    def fetch():
         import urllib
-        content = urllib.open(
+        content = urllib.urlopen(
             'http://project.lepture.com/liquidluck/themes.json'
         ).read()
         open(f, 'w').write(content)
 
+    if not os.path.exists(f) or os.stat(f).st_mtime + 600 < time.time():
+        fetch()
+
+    content = open(f).read()
+
     try:
         import json
         json_decode = json.loads
@@ -169,33 +174,51 @@ def __load_themes():
     return themes
 
 
+SEARCH_TEMPLATE = '''
+Theme: %(name)s
+Author: %(author)s
+Homepage: %(homepage)s
+
+'''
+
+
 def search(keyword=None):
-    #TODO
     themes = __load_themes()
-    if not keyword:
-        return themes
-    if keyword not in themes:
+
+    if keyword and keyword not in themes:
+        print("Can't find theme: %s" % keyword)
         return None
-    return themes[keyword]
+
+    if keyword:
+        themes = [themes[keyword]]
+
+    for keyword in themes:
+        theme = themes[keyword]
+        theme.update({'name': keyword})
+        print(SEARCH_TEMPLATE % theme)
+    return
 
 
 def install(keyword):
-    #TODO
     themes = __load_themes()
     if keyword not in themes:
         print("can't find theme %s" % keyword)
         return
     theme = themes[keyword]
-    return theme
+    repo = theme['repo']
+    output = '_themes/%s' % keyword
+    import subprocess
+    subprocess.call(['git', 'clone', repo, output])
 
 
 def main():
     parser = argparse.ArgumentParser(prog='liquidluck')
 
     parser.add_argument('command', nargs='?', default='build',
-                        help='build | create | help')
+                        help='build | create | search | install | help')
     parser.add_argument('-s', '--settings', default='settings.py',
                         help='setting file')
+    parser.add_argument('-t', '--theme', help='theme name')
     parser.add_argument(
         '-v', '--verbose', action='store_true', dest='detail_logging',
         help='show more logging'
@@ -213,6 +236,14 @@ def main():
         launch_help()
         return
 
+    if args.command == 'search':
+        search(args.theme)
+        return
+
+    if args.command == 'install':
+        install(args.theme)
+        return
+
     g.detail_logging = args.detail_logging
     enable_pretty_logging()
 
